@@ -15,14 +15,10 @@ from ._common import sdiskusage
 from ._common import usage_percent
 from ._compat import PY3
 from ._compat import unicode
+from ._exceptions import TimeoutExpired
 
 
-__all__ = ['TimeoutExpired', 'pid_exists', 'wait_pid', 'disk_usage',
-           'get_terminal_map']
-
-
-class TimeoutExpired(Exception):
-    pass
+__all__ = ['pid_exists', 'wait_pid', 'disk_usage', 'get_terminal_map']
 
 
 def pid_exists(pid):
@@ -53,7 +49,7 @@ def pid_exists(pid):
         return True
 
 
-def wait_pid(pid, timeout=None):
+def wait_pid(pid, timeout=None, proc_name=None):
     """Wait for process with pid 'pid' to terminate and return its
     exit status code as an integer.
 
@@ -67,7 +63,7 @@ def wait_pid(pid, timeout=None):
     def check_timeout(delay):
         if timeout is not None:
             if timer() >= stop_at:
-                raise TimeoutExpired()
+                raise TimeoutExpired(timeout, pid=pid, name=proc_name)
         time.sleep(delay)
         return min(delay * 2, 0.04)
 
@@ -160,7 +156,7 @@ def disk_usage(path):
     # User usage percent compared to the total amount of space
     # the user can use. This number would be higher if compared
     # to root's because the user has less space (usually -5%).
-    usage_percent_user = usage_percent(used, total_user, _round=1)
+    usage_percent_user = usage_percent(used, total_user, round_=1)
 
     # NB: the percentage is -5% than what shown by df due to
     # reserved blocks that we are currently not considering:
