@@ -58,8 +58,8 @@ import warnings
 from contextlib import closing
 
 from psutil import BSD
+from psutil import MACOS
 from psutil import OPENBSD
-from psutil import OSX
 from psutil import POSIX
 from psutil import WINDOWS
 from psutil._compat import PY3
@@ -285,7 +285,7 @@ class _BaseFSAPIsTests(object):
                 self.assertIsInstance(path, str)
 
 
-@unittest.skipIf(OSX and TRAVIS, "unreliable on TRAVIS")  # TODO
+@unittest.skipIf(MACOS and TRAVIS, "unreliable on TRAVIS")  # TODO
 @unittest.skipIf(ASCII_FS, "ASCII fs")
 @unittest.skipIf(not subprocess_supports_unicode(TESTFN_UNICODE),
                  "subprocess can't deal with unicode")
@@ -306,7 +306,7 @@ class TestFSAPIs(_BaseFSAPIsTests, unittest.TestCase):
                 return cls.funky_name in os.listdir(here)
 
 
-@unittest.skipIf(OSX and TRAVIS, "unreliable on TRAVIS")  # TODO
+@unittest.skipIf(MACOS and TRAVIS, "unreliable on TRAVIS")  # TODO
 @unittest.skipIf(not subprocess_supports_unicode(INVALID_NAME),
                  "subprocess can't deal with invalid unicode")
 class TestFSAPIsWithInvalidPath(_BaseFSAPIsTests, unittest.TestCase):
